package sun.nio.fs;

import java.net.URISyntaxException;
import java.net.URI;

class WindowsUriSupport
{
    private static final String IPV6_LITERAL_SUFFIX = ".ipv6-literal.net";
    
    private WindowsUriSupport() {
    }
    
    private static URI toUri(String s, boolean b, boolean b2) {
        String host;
        String s2;
        if (b) {
            int index = s.indexOf(92, 2);
            host = s.substring(2, index);
            s2 = s.substring(index).replace('\\', '/');
            if (host.endsWith(".ipv6-literal.net")) {
                host = host.substring(0, host.length() - ".ipv6-literal.net".length()).replace('-', ':').replace('s', '%');
            }
        }
        else {
            host = "";
            s2 = "/" + s.replace('\\', '/');
        }
        if (b2) {
            s2 += "/";
        }
        try {
            return new URI("file", host, s2, null);
        }
        catch (URISyntaxException detailMessage) {
            if (!b) {
                throw new AssertionError(detailMessage);
            }
            String s3 = "//" + s.replace('\\', '/');
            if (b2) {
                s3 += "/";
            }
            try {
                return new URI("file", null, s3, null);
            }
            catch (URISyntaxException detailMessage2) {
                throw new AssertionError(detailMessage2);
            }
        }
    }
    
    static URI toUri(WindowsPath absolutePath) {
        absolutePath = absolutePath.toAbsolutePath();
        String string = absolutePath.toString();
        boolean directory = false;
        if (!string.endsWith("\\")) {
            try {
                absolutePath.checkRead();
                directory = WindowsFileAttributes.get(absolutePath, true).isDirectory();
            }
            catch (SecurityException | WindowsException ex) {}
        }
        return toUri(string, absolutePath.isUnc(), (boolean)directory);
    }
    
    static WindowsPath fromUri(WindowsFileSystem windowsFileSystem, URI uri) {
        if (!uri.isAbsolute()) {
            throw new IllegalArgumentException("URI is not absolute");
        }
        if (uri.isOpaque()) {
            throw new IllegalArgumentException("URI is not hierarchical");
        }
        String scheme = uri.getScheme();
        if (scheme == null || !scheme.equalsIgnoreCase("file")) {
            throw new IllegalArgumentException("URI scheme is not \"file\"");
        }
        if (uri.getFragment() != null) {
            throw new IllegalArgumentException("URI has a fragment component");
        }
        if (uri.getQuery() != null) {
            throw new IllegalArgumentException("URI has a query component");
        }
        String str = uri.getPath();
        if (str.equals("")) {
            throw new IllegalArgumentException("URI path component is empty");
        }
        String authority = uri.getAuthority();
        if (authority != null && !authority.equals("")) {
            String str2 = uri.getHost();
            if (str2 == null) {
                throw new IllegalArgumentException("URI authority component has undefined host");
            }
            if (uri.getUserInfo() != null) {
                throw new IllegalArgumentException("URI authority component has user-info");
            }
            if (uri.getPort() != -1) {
                throw new IllegalArgumentException("URI authority component has port number");
            }
            if (str2.startsWith("[")) {
                str2 = str2.substring(1, str2.length() - 1).replace(':', '-').replace('%', 's') + ".ipv6-literal.net";
            }
            str = "\\\\" + str2 + str;
        }
        else if (str.length() > 2 && str.charAt(2) == ':') {
            str = str.substring(1);
        }
        return WindowsPath.parse(windowsFileSystem, str);
    }
}
